@@ -1,3 +1,10 @@
+# Copyright (C) 2014 Kieran Colford
+
+# Copying and distribution of this file, with or without modification,
+# are permitted in any medium without royalty provided the copyright
+# notice and this notice are preserved.  This file is offered as-is,
+# without any warranty.
+
 """The version module for this package.
 
 Whenever this module is imported, it will always attempt to update its
@@ -9,13 +16,6 @@ Currently, only git is a supported VCS.
 
 """
 
-# Copyright (C) 2014 Kieran Colford
-
-# Copying and distribution of this file, with or without modification,
-# are permitted in any medium without royalty provided the copyright
-# notice and this notice are preserved.  This file is offered as-is,
-# without any warranty.
-
 import os
 import re
 import subprocess
@@ -37,7 +37,15 @@ def callGit(args):
 
     out = subprocess.check_output(['git', '-C', getDir()] + args,
                                   stderr=subprocess.STDOUT)
-    return str(out, 'ascii')
+
+    # Convert the output to a string while maintaining compatibility
+    # with both python 3 and python 2.
+    try:
+        out = str(out, 'ascii')
+    except TypeError:
+        out = str(out)
+
+    return out
 
 
 def acceptsIgnoreRule(path):
@@ -81,20 +89,18 @@ def getVersion():
     """
 
     try:
-        ver = callGit(['describe', '--tags', '--abbrev=3', '--match=v*'])
+        ver = callGit(['describe', '--match=v*'])
         ver = ver.strip('v\n')
         ver = ver.replace('-', '.', 1)
         ver = ver.split('-')[0]
         updateCache(ver)
-    except OSError:
-        import _version
-        ver = _version.version
-    except CalledProcessError:
-        import _version
+    except (OSError, CalledProcessError):
+        from . import _version
         ver = _version.version
 
     return ver
 
+
 # Comment/Uncomment this to show/hide the function definitions above.
 # This is useful if the package doesn't want to show the internals of
 # its version generation or if a developer wants to read the module in
